if [ ! -e /etc/papersize ]
then
    /usr/bin/mkdir -p /etc
    /usr/bin/cp /etc/defaults/etc/papersize /etc/papersize
fi

